#' ---
#' title: "Table 1A: Census of Government Data"
#' author: "Michael Morse"
#' ---
#'
#+ echo = F, warning = F, message = F
rm(list = ls())
library(magrittr)
library(ggplot2)
library(readr)
library(readxl)
library(dplyr)

#' # Load the Data
#' There are three text files per Census of Government year. We only need the first one for any year actually because that's where
#' our variable of interest is. We focus on "Fines and Forfeits." The 2006 classification manual defines this as:
#' "revenue from penalties imposed for violations of law; civil penalties (e.g., for violating court orders); court fees if levied upon conviction of a crime or violation; court-ordered
#' restitutions to crime victims where government actually collects the monies; and forfeits of
#' deposits held for performance guarantees or against loss or damage (such as forfeited bail and collateral)."
#' They also explain that it excludes "enalties relating to tax delinquency (report at appropriate Tax code);
#' library fines (report at All Other General Current Charges, code A89);
#' and sale of confiscated property (use Miscellaneous General Revenue, NEC, code U99).

#+ warning = F, message = F
cog_12 <-
  read_csv("Data_1A.txt") %>%
  select(year = Year4, 
         id = ID, 
         state_code = `State Code`, 
         county_code = County, 
         type_code = `Type Code`,
         name = Name, 
         fips_state = `FIPS Code-State`, 
         pop = `Population`,
         zero_data = ZeroData, 
         imputed = `Imputed Record`,
         total_revenue = `Total Revenue`,
         total_revenue_own_sources = `Total Rev-Own Sources`,
         lfos = `Fines and Forfeits`) %>%
  mutate(lfos = lfos * 1000,
         total_revenue = total_revenue * 1000,
         total_revenue_own_sources = total_revenue_own_sources * 1000,
         lfos_per_cap = lfos / pop)

#' I made a dictionary that converted state codes to state names. I also used the data to create a second dictionary
#' of state population. Both will be used to create a figure of fines and forfeitures per capita with state names as
#' labels
state_name_dict <- read_excel("COG_Codebook.xlsx", sheet = "state")
state_pop_dict <- cog_12 %>% filter(type_code == 0) %>% mutate(state_code = as.double(state_code))
state_pop_dict <- state_pop_dict[, c("state_code", "pop")]

#' I create a new data_frame at the state-level.
state_12 <-
  cog_12 %>%
  group_by(state_code) %>%
  summarise(lfos = sum(lfos)) %>%
  mutate(state_code = as.double(state_code)) %>%
  left_join(state_name_dict, by = c("state_code" = "state")) %>%
  left_join(state_pop_dict) %>%
  mutate(lfos_per_cap = (lfos / pop)  %>% round(digits = 2)) %>%
  arrange(desc(lfos_per_cap))

#' # Plot
#+ warning = F, message = F

caption <- "Note: The data come from 2012 Census of Governments: State & Local Finances, collected by the U.S. Census Bureau. Fines and forfeits (code U30) are defined as \"revenue from penalties imposed for violations of law; civil penalties (e.g., for violating court orders); court fees if levied upon conviction of a crime or violation; court-ordered restitutions to crime victims where government actually collects the monies; and forfeits of deposits held for performance guarantees or against loss or damage (such as forfeited bail and collateral).\" It excludes \"penalties relating to tax delinquency; library fines; and sale of confiscated property.\""
caption <- paste0(strwrap(caption, 140), sep="", collapse="\n")

#' Need the dev version of ggplot2. 2.1.0
g <-
  state_12 %>%
  mutate(state_plot = factor(state_full, levels = state_full[order(lfos_per_cap)])) %>%
  filter(state_plot != "District of Columbia") %>%
  ggplot(aes(x = state_plot, y = lfos_per_cap)) +
  geom_bar(aes(fill = ifelse(state_plot == "Alabama", T, F)),
           stat = "identity",
           show.legend = F) +
  scale_fill_manual(values=c("grey", "black")) +
  scale_y_continuous(labels = scales::dollar_format()) +
  labs(y = "Fines and Forfeitures per Capita",
       x = "State",
       title = "Fines and Forfeitures Across States (2012)",
       caption = caption) +
  coord_flip() +
  theme(plot.title = element_text(hjust = 0.5),
        plot.caption = element_text(hjust=0, margin= margin(t=15)),
        panel.background = element_blank(),
        axis.line.x = element_line(color="#2b2b2b", size=0.35),
        axis.line.y = element_line(color="#2b2b2b", size=0.35))

g

