#' ---
#' title: "Replicate Figure 4B3: Montgomery, Alacourt v. Municipal"
#' author: "Michael Morse"
#' ---
#+ echo = F, warning = F, message = F
rm(list = ls())
library(magrittr)
library(dplyr)
library(stringr)
library(purrr)
library(readr)
library(readxl)
library(ggplot2)
library(lubridate)
library(knitr)

#' # Load Data
#' The data is a list of three data frames, extract each df for ease. 
#' Combo is a data frame that, for ease, combines 2013 case-level data from Montgomery county (via our 2013 census) and Montgomery municipality. 
#' traffic13 is a census of Montgomery municipal court traffic cases .
#' cra13 is a census of Montgomery municipal court criminal cases. It is included as part of combo, above. However, cra13 has an additional variable (file_date).
#+ warning = F, messsage = F
data <- readRDS("Data_4B3.rds")
combo <- data$combo
traffic13 <- data$traffic13
cra13 <- data$cra13

#' # Create Table Piecemeal
#' The final table will create seven quantities of interest, three for Montgomery County data and four for City of Montgomery data.

#' ## Montgomery County
#' Create regular expressions to categrorize a defendant's conviction status.
county_convicted <- "((?<!NOT)GUILTY)|(CONVICTED)"
county_not_convicted <-  "(NOL PROS)|(DISMISS)"

#' Felony Conviction Montgomery County
#' Determine the total amount due in all Montgomery County felony cases that result in conviction. 
p1 <-
  combo %>%
  filter(type_desc == "FELONY",
         str_detect(court.action, regex(county_convicted, ignore_case = T))) %>%
  summarise(n = n(),
            amount.due = sum(amount.due)) %>%
  mutate(label = "Felony Guilty Montgomery County")

#' Misdemeanor Conviction Montgomery County
#' Determine the total amount due in all Montgomery County misdemeanor cases that result in conviction. 
p2 <-
  combo %>%
  filter(area == "County",
         type_desc == "MISDEMEANOR",
         str_detect(court.action, regex(county_convicted, ignore_case = T))) %>%
  summarise(n = n(),
            amount.due = sum(amount.due)) %>%
  mutate(label = "Misdemeanor Convicted Montgomery County")

#' Not Guilty Montgomery County
#' 
p3 <-
  combo %>%
  filter(area == "County",
         str_detect(court.action, regex(county_not_convicted, ignore_case = T))) %>%
  summarise(n = n(),
            amount.due = sum(amount.due)) %>%
  mutate(label = "Not Convicted Montgomery County")

#' ## City of Montgomery
#' Create regular expressions to categrorize a defendant's conviction status.

muni_convicted <- c("GUILTY", "JAIL SENTENCE", "CONDITIONAL GUILTY")
muni_not_convicted <- c("NOL PROSSED",
                        "Dismissed with Court Cost",
                        "NOL-PROSSED WITH LEAVE TO REINSTATE",
                        "Nol-Prossed with Court Cost",
                        "Nol-Prosessed with Restitution to Victim")

#' Misdemneaor Guilty Criminal City of Montgomery
p4 <-
  combo %>%
  filter(area == "Municipality",
         type_desc == "MISDEMEANOR",
         court.action %in% muni_convicted) %>%
  summarise(n = n(),
            amount.due = sum(amount.due)) %>%
  mutate(label = "Misdemeanor Convicted Criminal City of Montgomery")

#' Not Convicted Criminal City of Montgomery

p5 <-
  combo %>%
  filter(area == "Municipality",
         court.action %in% muni_not_convicted) %>%
  summarise(n = n(),
            amount.due = sum(amount.due)) %>%
  mutate(label = "Not Convicted Criminal City of Montgomery")

#' ## Other

#' Convicted Traffic LFOs Jan 2013 City of Montgomery

p6 <-
  traffic13 %>%
  mutate(disposition = str_trim(court.action),
         convicted = ifelse(str_detect(court.action, regex("GUILTY", ignore_case = T)), T, F)) %>%
  filter(convicted,
         mdy(file_date) %>% month() == 1) %>%
  summarise(n = n(),
            amount.due = sum(amount.due)) %>%
  mutate(label = "Convicted Traffic LFOs Jan 2013 City of Montgomery")

#' Convicted Criminal LFOs Jan 2013 City of Montgomery

p7 <-
  cra13 %>%
  filter(mdy(file_date) %>% month() == 1) %>%
  summarise(n = n(),
            amount.due = sum(amount.due)) %>%
  mutate(label = "Convicted Criminal LFOs Jan 2013 City of Montgomery")

try <- 
  combo %>%
  filter(area == "Municipality") %>%
  filter(mdy(file_date) %>% month() == 1) %>%
  summarise(n = n(),
            amount.due = sum(amount.due)) %>%
  mutate(label = "Convicted Criminal LFOs Jan 2013 City of Montgomery")


#' # Put it All Together

result <- bind_rows(list(p1, p2, p3, p4, p5, p6, p7))

result %>% kable()




